@@ -17,7 +17,7 @@ a fast and powerful graphical file manager
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/000/606/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
